# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['UserArgs', 'User']

@pulumi.input_type
class UserArgs:
    def __init__(__self__, *,
                 user_name: pulumi.Input[builtins.str],
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 email: Optional[pulumi.Input[builtins.str]] = None,
                 email_is_verify: Optional[pulumi.Input[builtins.bool]] = None,
                 groups: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 login_profile: Optional[pulumi.Input['UserLoginProfileArgs']] = None,
                 mobile_phone: Optional[pulumi.Input[builtins.str]] = None,
                 mobile_phone_is_verify: Optional[pulumi.Input[builtins.bool]] = None,
                 policies: Optional[pulumi.Input[Sequence[pulumi.Input['UserPolicyArgs']]]] = None,
                 security_config: Optional[pulumi.Input['UserSecurityConfigArgs']] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['UserTagArgs']]]] = None):
        """
        The set of arguments for constructing a User resource.
        :param pulumi.Input[builtins.str] user_name: 子用户名称，用户名。长度1~64，支持英文、数字、下划线、和.-@符号。
        :param pulumi.Input[builtins.str] description: 子用户对应的描述信息，长度不超过255。
        :param pulumi.Input[builtins.str] display_name: 子用户对应的展示名称，用户显示名。长度1~128，仅支持中文、英文、数字、空格和.-_@符号。
        :param pulumi.Input[builtins.str] email: 子用户对应的电子邮件地址。
        :param pulumi.Input[builtins.bool] email_is_verify: 子用户电子邮件地址是否已验证。true代表已验证，false代表未验证。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] groups: 子用户归属的用户组。
        :param pulumi.Input['UserLoginProfileArgs'] login_profile: 子用户的登录配置。
        :param pulumi.Input[builtins.str] mobile_phone: 子用户对应的手机号。
        :param pulumi.Input[builtins.bool] mobile_phone_is_verify: 子用户手机号是否已验证。true代表已验证，false代表未验证。
        :param pulumi.Input['UserSecurityConfigArgs'] security_config: 子用户的操作保护配置。
        """
        pulumi.set(__self__, "user_name", user_name)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if email is not None:
            pulumi.set(__self__, "email", email)
        if email_is_verify is not None:
            pulumi.set(__self__, "email_is_verify", email_is_verify)
        if groups is not None:
            pulumi.set(__self__, "groups", groups)
        if login_profile is not None:
            pulumi.set(__self__, "login_profile", login_profile)
        if mobile_phone is not None:
            pulumi.set(__self__, "mobile_phone", mobile_phone)
        if mobile_phone_is_verify is not None:
            pulumi.set(__self__, "mobile_phone_is_verify", mobile_phone_is_verify)
        if policies is not None:
            pulumi.set(__self__, "policies", policies)
        if security_config is not None:
            pulumi.set(__self__, "security_config", security_config)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> pulumi.Input[builtins.str]:
        """
        子用户名称，用户名。长度1~64，支持英文、数字、下划线、和.-@符号。
        """
        return pulumi.get(self, "user_name")

    @user_name.setter
    def user_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "user_name", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        子用户对应的描述信息，长度不超过255。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        子用户对应的展示名称，用户显示名。长度1~128，仅支持中文、英文、数字、空格和.-_@符号。
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter
    def email(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        子用户对应的电子邮件地址。
        """
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "email", value)

    @property
    @pulumi.getter(name="emailIsVerify")
    def email_is_verify(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        子用户电子邮件地址是否已验证。true代表已验证，false代表未验证。
        """
        return pulumi.get(self, "email_is_verify")

    @email_is_verify.setter
    def email_is_verify(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "email_is_verify", value)

    @property
    @pulumi.getter
    def groups(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        子用户归属的用户组。
        """
        return pulumi.get(self, "groups")

    @groups.setter
    def groups(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "groups", value)

    @property
    @pulumi.getter(name="loginProfile")
    def login_profile(self) -> Optional[pulumi.Input['UserLoginProfileArgs']]:
        """
        子用户的登录配置。
        """
        return pulumi.get(self, "login_profile")

    @login_profile.setter
    def login_profile(self, value: Optional[pulumi.Input['UserLoginProfileArgs']]):
        pulumi.set(self, "login_profile", value)

    @property
    @pulumi.getter(name="mobilePhone")
    def mobile_phone(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        子用户对应的手机号。
        """
        return pulumi.get(self, "mobile_phone")

    @mobile_phone.setter
    def mobile_phone(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "mobile_phone", value)

    @property
    @pulumi.getter(name="mobilePhoneIsVerify")
    def mobile_phone_is_verify(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        子用户手机号是否已验证。true代表已验证，false代表未验证。
        """
        return pulumi.get(self, "mobile_phone_is_verify")

    @mobile_phone_is_verify.setter
    def mobile_phone_is_verify(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "mobile_phone_is_verify", value)

    @property
    @pulumi.getter
    def policies(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['UserPolicyArgs']]]]:
        return pulumi.get(self, "policies")

    @policies.setter
    def policies(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['UserPolicyArgs']]]]):
        pulumi.set(self, "policies", value)

    @property
    @pulumi.getter(name="securityConfig")
    def security_config(self) -> Optional[pulumi.Input['UserSecurityConfigArgs']]:
        """
        子用户的操作保护配置。
        """
        return pulumi.get(self, "security_config")

    @security_config.setter
    def security_config(self, value: Optional[pulumi.Input['UserSecurityConfigArgs']]):
        pulumi.set(self, "security_config", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['UserTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['UserTagArgs']]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _UserState:
    def __init__(__self__, *,
                 access_keys: Optional[pulumi.Input[Sequence[pulumi.Input['UserAccessKeyArgs']]]] = None,
                 account_id: Optional[pulumi.Input[builtins.float]] = None,
                 create_date: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 email: Optional[pulumi.Input[builtins.str]] = None,
                 email_is_verify: Optional[pulumi.Input[builtins.bool]] = None,
                 groups: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 login_profile: Optional[pulumi.Input['UserLoginProfileArgs']] = None,
                 mobile_phone: Optional[pulumi.Input[builtins.str]] = None,
                 mobile_phone_is_verify: Optional[pulumi.Input[builtins.bool]] = None,
                 policies: Optional[pulumi.Input[Sequence[pulumi.Input['UserPolicyArgs']]]] = None,
                 security_config: Optional[pulumi.Input['UserSecurityConfigArgs']] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['UserTagArgs']]]] = None,
                 trn: Optional[pulumi.Input[builtins.str]] = None,
                 update_date: Optional[pulumi.Input[builtins.str]] = None,
                 user_id: Optional[pulumi.Input[builtins.int]] = None,
                 user_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering User resources.
        :param pulumi.Input[builtins.float] account_id: 子用户归属的主账号。
        :param pulumi.Input[builtins.str] create_date: 子用户对应的创建时间。
        :param pulumi.Input[builtins.str] description: 子用户对应的描述信息，长度不超过255。
        :param pulumi.Input[builtins.str] display_name: 子用户对应的展示名称，用户显示名。长度1~128，仅支持中文、英文、数字、空格和.-_@符号。
        :param pulumi.Input[builtins.str] email: 子用户对应的电子邮件地址。
        :param pulumi.Input[builtins.bool] email_is_verify: 子用户电子邮件地址是否已验证。true代表已验证，false代表未验证。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] groups: 子用户归属的用户组。
        :param pulumi.Input['UserLoginProfileArgs'] login_profile: 子用户的登录配置。
        :param pulumi.Input[builtins.str] mobile_phone: 子用户对应的手机号。
        :param pulumi.Input[builtins.bool] mobile_phone_is_verify: 子用户手机号是否已验证。true代表已验证，false代表未验证。
        :param pulumi.Input['UserSecurityConfigArgs'] security_config: 子用户的操作保护配置。
        :param pulumi.Input[builtins.str] trn: 子用户对应的Trn表达式。
        :param pulumi.Input[builtins.str] update_date: 子用户对应的更新时间。
        :param pulumi.Input[builtins.int] user_id: 子用户的ID。
        :param pulumi.Input[builtins.str] user_name: 子用户名称，用户名。长度1~64，支持英文、数字、下划线、和.-@符号。
        """
        if access_keys is not None:
            pulumi.set(__self__, "access_keys", access_keys)
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if create_date is not None:
            pulumi.set(__self__, "create_date", create_date)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if email is not None:
            pulumi.set(__self__, "email", email)
        if email_is_verify is not None:
            pulumi.set(__self__, "email_is_verify", email_is_verify)
        if groups is not None:
            pulumi.set(__self__, "groups", groups)
        if login_profile is not None:
            pulumi.set(__self__, "login_profile", login_profile)
        if mobile_phone is not None:
            pulumi.set(__self__, "mobile_phone", mobile_phone)
        if mobile_phone_is_verify is not None:
            pulumi.set(__self__, "mobile_phone_is_verify", mobile_phone_is_verify)
        if policies is not None:
            pulumi.set(__self__, "policies", policies)
        if security_config is not None:
            pulumi.set(__self__, "security_config", security_config)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if trn is not None:
            pulumi.set(__self__, "trn", trn)
        if update_date is not None:
            pulumi.set(__self__, "update_date", update_date)
        if user_id is not None:
            pulumi.set(__self__, "user_id", user_id)
        if user_name is not None:
            pulumi.set(__self__, "user_name", user_name)

    @property
    @pulumi.getter(name="accessKeys")
    def access_keys(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['UserAccessKeyArgs']]]]:
        return pulumi.get(self, "access_keys")

    @access_keys.setter
    def access_keys(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['UserAccessKeyArgs']]]]):
        pulumi.set(self, "access_keys", value)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        子用户归属的主账号。
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "account_id", value)

    @property
    @pulumi.getter(name="createDate")
    def create_date(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        子用户对应的创建时间。
        """
        return pulumi.get(self, "create_date")

    @create_date.setter
    def create_date(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "create_date", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        子用户对应的描述信息，长度不超过255。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        子用户对应的展示名称，用户显示名。长度1~128，仅支持中文、英文、数字、空格和.-_@符号。
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter
    def email(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        子用户对应的电子邮件地址。
        """
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "email", value)

    @property
    @pulumi.getter(name="emailIsVerify")
    def email_is_verify(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        子用户电子邮件地址是否已验证。true代表已验证，false代表未验证。
        """
        return pulumi.get(self, "email_is_verify")

    @email_is_verify.setter
    def email_is_verify(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "email_is_verify", value)

    @property
    @pulumi.getter
    def groups(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        子用户归属的用户组。
        """
        return pulumi.get(self, "groups")

    @groups.setter
    def groups(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "groups", value)

    @property
    @pulumi.getter(name="loginProfile")
    def login_profile(self) -> Optional[pulumi.Input['UserLoginProfileArgs']]:
        """
        子用户的登录配置。
        """
        return pulumi.get(self, "login_profile")

    @login_profile.setter
    def login_profile(self, value: Optional[pulumi.Input['UserLoginProfileArgs']]):
        pulumi.set(self, "login_profile", value)

    @property
    @pulumi.getter(name="mobilePhone")
    def mobile_phone(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        子用户对应的手机号。
        """
        return pulumi.get(self, "mobile_phone")

    @mobile_phone.setter
    def mobile_phone(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "mobile_phone", value)

    @property
    @pulumi.getter(name="mobilePhoneIsVerify")
    def mobile_phone_is_verify(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        子用户手机号是否已验证。true代表已验证，false代表未验证。
        """
        return pulumi.get(self, "mobile_phone_is_verify")

    @mobile_phone_is_verify.setter
    def mobile_phone_is_verify(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "mobile_phone_is_verify", value)

    @property
    @pulumi.getter
    def policies(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['UserPolicyArgs']]]]:
        return pulumi.get(self, "policies")

    @policies.setter
    def policies(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['UserPolicyArgs']]]]):
        pulumi.set(self, "policies", value)

    @property
    @pulumi.getter(name="securityConfig")
    def security_config(self) -> Optional[pulumi.Input['UserSecurityConfigArgs']]:
        """
        子用户的操作保护配置。
        """
        return pulumi.get(self, "security_config")

    @security_config.setter
    def security_config(self, value: Optional[pulumi.Input['UserSecurityConfigArgs']]):
        pulumi.set(self, "security_config", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['UserTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['UserTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def trn(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        子用户对应的Trn表达式。
        """
        return pulumi.get(self, "trn")

    @trn.setter
    def trn(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "trn", value)

    @property
    @pulumi.getter(name="updateDate")
    def update_date(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        子用户对应的更新时间。
        """
        return pulumi.get(self, "update_date")

    @update_date.setter
    def update_date(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "update_date", value)

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        子用户的ID。
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "user_id", value)

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        子用户名称，用户名。长度1~64，支持英文、数字、下划线、和.-@符号。
        """
        return pulumi.get(self, "user_name")

    @user_name.setter
    def user_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "user_name", value)


@pulumi.type_token("bytepluscc:iam/user:User")
class User(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 email: Optional[pulumi.Input[builtins.str]] = None,
                 email_is_verify: Optional[pulumi.Input[builtins.bool]] = None,
                 groups: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 login_profile: Optional[pulumi.Input[Union['UserLoginProfileArgs', 'UserLoginProfileArgsDict']]] = None,
                 mobile_phone: Optional[pulumi.Input[builtins.str]] = None,
                 mobile_phone_is_verify: Optional[pulumi.Input[builtins.bool]] = None,
                 policies: Optional[pulumi.Input[Sequence[pulumi.Input[Union['UserPolicyArgs', 'UserPolicyArgsDict']]]]] = None,
                 security_config: Optional[pulumi.Input[Union['UserSecurityConfigArgs', 'UserSecurityConfigArgsDict']]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['UserTagArgs', 'UserTagArgsDict']]]]] = None,
                 user_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        IAM子用户是访问控制的一种身份，由账号或是拥有权限的用户创建。用户被授予权限后，可登录控制台或使用访问密钥调用API访问云资源。

        ## Import

        ```sh
        $ pulumi import bytepluscc:iam/user:User example "user_name"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: 子用户对应的描述信息，长度不超过255。
        :param pulumi.Input[builtins.str] display_name: 子用户对应的展示名称，用户显示名。长度1~128，仅支持中文、英文、数字、空格和.-_@符号。
        :param pulumi.Input[builtins.str] email: 子用户对应的电子邮件地址。
        :param pulumi.Input[builtins.bool] email_is_verify: 子用户电子邮件地址是否已验证。true代表已验证，false代表未验证。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] groups: 子用户归属的用户组。
        :param pulumi.Input[Union['UserLoginProfileArgs', 'UserLoginProfileArgsDict']] login_profile: 子用户的登录配置。
        :param pulumi.Input[builtins.str] mobile_phone: 子用户对应的手机号。
        :param pulumi.Input[builtins.bool] mobile_phone_is_verify: 子用户手机号是否已验证。true代表已验证，false代表未验证。
        :param pulumi.Input[Union['UserSecurityConfigArgs', 'UserSecurityConfigArgsDict']] security_config: 子用户的操作保护配置。
        :param pulumi.Input[builtins.str] user_name: 子用户名称，用户名。长度1~64，支持英文、数字、下划线、和.-@符号。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: UserArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        IAM子用户是访问控制的一种身份，由账号或是拥有权限的用户创建。用户被授予权限后，可登录控制台或使用访问密钥调用API访问云资源。

        ## Import

        ```sh
        $ pulumi import bytepluscc:iam/user:User example "user_name"
        ```

        :param str resource_name: The name of the resource.
        :param UserArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(UserArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 email: Optional[pulumi.Input[builtins.str]] = None,
                 email_is_verify: Optional[pulumi.Input[builtins.bool]] = None,
                 groups: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 login_profile: Optional[pulumi.Input[Union['UserLoginProfileArgs', 'UserLoginProfileArgsDict']]] = None,
                 mobile_phone: Optional[pulumi.Input[builtins.str]] = None,
                 mobile_phone_is_verify: Optional[pulumi.Input[builtins.bool]] = None,
                 policies: Optional[pulumi.Input[Sequence[pulumi.Input[Union['UserPolicyArgs', 'UserPolicyArgsDict']]]]] = None,
                 security_config: Optional[pulumi.Input[Union['UserSecurityConfigArgs', 'UserSecurityConfigArgsDict']]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['UserTagArgs', 'UserTagArgsDict']]]]] = None,
                 user_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = UserArgs.__new__(UserArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["display_name"] = display_name
            __props__.__dict__["email"] = email
            __props__.__dict__["email_is_verify"] = email_is_verify
            __props__.__dict__["groups"] = groups
            __props__.__dict__["login_profile"] = login_profile
            __props__.__dict__["mobile_phone"] = mobile_phone
            __props__.__dict__["mobile_phone_is_verify"] = mobile_phone_is_verify
            __props__.__dict__["policies"] = policies
            __props__.__dict__["security_config"] = security_config
            __props__.__dict__["tags"] = tags
            if user_name is None and not opts.urn:
                raise TypeError("Missing required property 'user_name'")
            __props__.__dict__["user_name"] = user_name
            __props__.__dict__["access_keys"] = None
            __props__.__dict__["account_id"] = None
            __props__.__dict__["create_date"] = None
            __props__.__dict__["trn"] = None
            __props__.__dict__["update_date"] = None
            __props__.__dict__["user_id"] = None
        super(User, __self__).__init__(
            'bytepluscc:iam/user:User',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            access_keys: Optional[pulumi.Input[Sequence[pulumi.Input[Union['UserAccessKeyArgs', 'UserAccessKeyArgsDict']]]]] = None,
            account_id: Optional[pulumi.Input[builtins.float]] = None,
            create_date: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            display_name: Optional[pulumi.Input[builtins.str]] = None,
            email: Optional[pulumi.Input[builtins.str]] = None,
            email_is_verify: Optional[pulumi.Input[builtins.bool]] = None,
            groups: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            login_profile: Optional[pulumi.Input[Union['UserLoginProfileArgs', 'UserLoginProfileArgsDict']]] = None,
            mobile_phone: Optional[pulumi.Input[builtins.str]] = None,
            mobile_phone_is_verify: Optional[pulumi.Input[builtins.bool]] = None,
            policies: Optional[pulumi.Input[Sequence[pulumi.Input[Union['UserPolicyArgs', 'UserPolicyArgsDict']]]]] = None,
            security_config: Optional[pulumi.Input[Union['UserSecurityConfigArgs', 'UserSecurityConfigArgsDict']]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['UserTagArgs', 'UserTagArgsDict']]]]] = None,
            trn: Optional[pulumi.Input[builtins.str]] = None,
            update_date: Optional[pulumi.Input[builtins.str]] = None,
            user_id: Optional[pulumi.Input[builtins.int]] = None,
            user_name: Optional[pulumi.Input[builtins.str]] = None) -> 'User':
        """
        Get an existing User resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.float] account_id: 子用户归属的主账号。
        :param pulumi.Input[builtins.str] create_date: 子用户对应的创建时间。
        :param pulumi.Input[builtins.str] description: 子用户对应的描述信息，长度不超过255。
        :param pulumi.Input[builtins.str] display_name: 子用户对应的展示名称，用户显示名。长度1~128，仅支持中文、英文、数字、空格和.-_@符号。
        :param pulumi.Input[builtins.str] email: 子用户对应的电子邮件地址。
        :param pulumi.Input[builtins.bool] email_is_verify: 子用户电子邮件地址是否已验证。true代表已验证，false代表未验证。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] groups: 子用户归属的用户组。
        :param pulumi.Input[Union['UserLoginProfileArgs', 'UserLoginProfileArgsDict']] login_profile: 子用户的登录配置。
        :param pulumi.Input[builtins.str] mobile_phone: 子用户对应的手机号。
        :param pulumi.Input[builtins.bool] mobile_phone_is_verify: 子用户手机号是否已验证。true代表已验证，false代表未验证。
        :param pulumi.Input[Union['UserSecurityConfigArgs', 'UserSecurityConfigArgsDict']] security_config: 子用户的操作保护配置。
        :param pulumi.Input[builtins.str] trn: 子用户对应的Trn表达式。
        :param pulumi.Input[builtins.str] update_date: 子用户对应的更新时间。
        :param pulumi.Input[builtins.int] user_id: 子用户的ID。
        :param pulumi.Input[builtins.str] user_name: 子用户名称，用户名。长度1~64，支持英文、数字、下划线、和.-@符号。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _UserState.__new__(_UserState)

        __props__.__dict__["access_keys"] = access_keys
        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["create_date"] = create_date
        __props__.__dict__["description"] = description
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["email"] = email
        __props__.__dict__["email_is_verify"] = email_is_verify
        __props__.__dict__["groups"] = groups
        __props__.__dict__["login_profile"] = login_profile
        __props__.__dict__["mobile_phone"] = mobile_phone
        __props__.__dict__["mobile_phone_is_verify"] = mobile_phone_is_verify
        __props__.__dict__["policies"] = policies
        __props__.__dict__["security_config"] = security_config
        __props__.__dict__["tags"] = tags
        __props__.__dict__["trn"] = trn
        __props__.__dict__["update_date"] = update_date
        __props__.__dict__["user_id"] = user_id
        __props__.__dict__["user_name"] = user_name
        return User(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accessKeys")
    def access_keys(self) -> pulumi.Output[Sequence['outputs.UserAccessKey']]:
        return pulumi.get(self, "access_keys")

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[builtins.float]:
        """
        子用户归属的主账号。
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter(name="createDate")
    def create_date(self) -> pulumi.Output[builtins.str]:
        """
        子用户对应的创建时间。
        """
        return pulumi.get(self, "create_date")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        子用户对应的描述信息，长度不超过255。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[builtins.str]:
        """
        子用户对应的展示名称，用户显示名。长度1~128，仅支持中文、英文、数字、空格和.-_@符号。
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def email(self) -> pulumi.Output[builtins.str]:
        """
        子用户对应的电子邮件地址。
        """
        return pulumi.get(self, "email")

    @property
    @pulumi.getter(name="emailIsVerify")
    def email_is_verify(self) -> pulumi.Output[builtins.bool]:
        """
        子用户电子邮件地址是否已验证。true代表已验证，false代表未验证。
        """
        return pulumi.get(self, "email_is_verify")

    @property
    @pulumi.getter
    def groups(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        子用户归属的用户组。
        """
        return pulumi.get(self, "groups")

    @property
    @pulumi.getter(name="loginProfile")
    def login_profile(self) -> pulumi.Output['outputs.UserLoginProfile']:
        """
        子用户的登录配置。
        """
        return pulumi.get(self, "login_profile")

    @property
    @pulumi.getter(name="mobilePhone")
    def mobile_phone(self) -> pulumi.Output[builtins.str]:
        """
        子用户对应的手机号。
        """
        return pulumi.get(self, "mobile_phone")

    @property
    @pulumi.getter(name="mobilePhoneIsVerify")
    def mobile_phone_is_verify(self) -> pulumi.Output[builtins.bool]:
        """
        子用户手机号是否已验证。true代表已验证，false代表未验证。
        """
        return pulumi.get(self, "mobile_phone_is_verify")

    @property
    @pulumi.getter
    def policies(self) -> pulumi.Output[Sequence['outputs.UserPolicy']]:
        return pulumi.get(self, "policies")

    @property
    @pulumi.getter(name="securityConfig")
    def security_config(self) -> pulumi.Output['outputs.UserSecurityConfig']:
        """
        子用户的操作保护配置。
        """
        return pulumi.get(self, "security_config")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.UserTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def trn(self) -> pulumi.Output[builtins.str]:
        """
        子用户对应的Trn表达式。
        """
        return pulumi.get(self, "trn")

    @property
    @pulumi.getter(name="updateDate")
    def update_date(self) -> pulumi.Output[builtins.str]:
        """
        子用户对应的更新时间。
        """
        return pulumi.get(self, "update_date")

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> pulumi.Output[builtins.int]:
        """
        子用户的ID。
        """
        return pulumi.get(self, "user_id")

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> pulumi.Output[builtins.str]:
        """
        子用户名称，用户名。长度1~64，支持英文、数字、下划线、和.-@符号。
        """
        return pulumi.get(self, "user_name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['SnapshotArgs', 'Snapshot']

@pulumi.input_type
class SnapshotArgs:
    def __init__(__self__, *,
                 snapshot_name: pulumi.Input[builtins.str],
                 volume_id: pulumi.Input[builtins.str],
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 retention_days: Optional[pulumi.Input[builtins.int]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['SnapshotTagArgs']]]] = None):
        """
        The set of arguments for constructing a Snapshot resource.
        :param pulumi.Input[builtins.str] snapshot_name: 创建的快照名称。命名规范如下：长度限制为1~128个字符。只能包含中文、字母、数字、下划线（_）、中划线（-）和英文句号（.）。为防止和自动快照的名称冲突，不能以“auto”开头。
        :param pulumi.Input[builtins.str] volume_id: 快照相关的云盘ID。
        :param pulumi.Input[builtins.str] description: 快照描述信息，默认为空，长度限制为0~255个字符。
        :param pulumi.Input[builtins.str] project_name: 快照所要加入的Project（项目）名称。注意快照不会继承云盘的项目，即快照与云盘可以所属不同的项目。如果您在创建快照时未设置ProjectName，快照会默认加入default项目。
        :param pulumi.Input[builtins.int] retention_days: 快照保留时间，单位为天，取值说明如下：空：永久保留快照 。1~65536：指定保存天数。默认为空，即默认永久保留快照。说明快照保留时间从快照创建时刻开始计算。
        """
        pulumi.set(__self__, "snapshot_name", snapshot_name)
        pulumi.set(__self__, "volume_id", volume_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if retention_days is not None:
            pulumi.set(__self__, "retention_days", retention_days)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="snapshotName")
    def snapshot_name(self) -> pulumi.Input[builtins.str]:
        """
        创建的快照名称。命名规范如下：长度限制为1~128个字符。只能包含中文、字母、数字、下划线（_）、中划线（-）和英文句号（.）。为防止和自动快照的名称冲突，不能以“auto”开头。
        """
        return pulumi.get(self, "snapshot_name")

    @snapshot_name.setter
    def snapshot_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "snapshot_name", value)

    @property
    @pulumi.getter(name="volumeId")
    def volume_id(self) -> pulumi.Input[builtins.str]:
        """
        快照相关的云盘ID。
        """
        return pulumi.get(self, "volume_id")

    @volume_id.setter
    def volume_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "volume_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        快照描述信息，默认为空，长度限制为0~255个字符。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        快照所要加入的Project（项目）名称。注意快照不会继承云盘的项目，即快照与云盘可以所属不同的项目。如果您在创建快照时未设置ProjectName，快照会默认加入default项目。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="retentionDays")
    def retention_days(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        快照保留时间，单位为天，取值说明如下：空：永久保留快照 。1~65536：指定保存天数。默认为空，即默认永久保留快照。说明快照保留时间从快照创建时刻开始计算。
        """
        return pulumi.get(self, "retention_days")

    @retention_days.setter
    def retention_days(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "retention_days", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SnapshotTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SnapshotTagArgs']]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _SnapshotState:
    def __init__(__self__, *,
                 creation_time: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 image_id: Optional[pulumi.Input[builtins.str]] = None,
                 instant_access: Optional[pulumi.Input[builtins.bool]] = None,
                 progress: Optional[pulumi.Input[builtins.int]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 retention_days: Optional[pulumi.Input[builtins.int]] = None,
                 shared: Optional[pulumi.Input[builtins.bool]] = None,
                 snapshot_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 snapshot_id: Optional[pulumi.Input[builtins.str]] = None,
                 snapshot_name: Optional[pulumi.Input[builtins.str]] = None,
                 snapshot_type: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['SnapshotTagArgs']]]] = None,
                 volume_id: Optional[pulumi.Input[builtins.str]] = None,
                 volume_kind: Optional[pulumi.Input[builtins.str]] = None,
                 volume_name: Optional[pulumi.Input[builtins.str]] = None,
                 volume_size: Optional[pulumi.Input[builtins.int]] = None,
                 volume_status: Optional[pulumi.Input[builtins.str]] = None,
                 volume_type: Optional[pulumi.Input[builtins.str]] = None,
                 zone_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Snapshot resources.
        :param pulumi.Input[builtins.str] creation_time: 快照创建时间。
        :param pulumi.Input[builtins.str] description: 快照描述信息，默认为空，长度限制为0~255个字符。
        :param pulumi.Input[builtins.str] image_id: 镜像ID
        :param pulumi.Input[builtins.bool] instant_access: 快照是否开启极速可用能力，取值说明如下：true：已开启极速可用能力。false：未开启极速可用能力。
        :param pulumi.Input[builtins.int] progress: 快照转储进度。
        :param pulumi.Input[builtins.str] project_name: 快照所要加入的Project（项目）名称。注意快照不会继承云盘的项目，即快照与云盘可以所属不同的项目。如果您在创建快照时未设置ProjectName，快照会默认加入default项目。
        :param pulumi.Input[builtins.int] retention_days: 快照保留时间，单位为天，取值说明如下：空：永久保留快照 。1~65536：指定保存天数。默认为空，即默认永久保留快照。说明快照保留时间从快照创建时刻开始计算。
        :param pulumi.Input[builtins.bool] shared: 快照是否共享。
        :param pulumi.Input[builtins.str] snapshot_group_id: 快照一致性组ID。
        :param pulumi.Input[builtins.str] snapshot_id: 快照ID。
        :param pulumi.Input[builtins.str] snapshot_name: 创建的快照名称。命名规范如下：长度限制为1~128个字符。只能包含中文、字母、数字、下划线（_）、中划线（-）和英文句号（.）。为防止和自动快照的名称冲突，不能以“auto”开头。
        :param pulumi.Input[builtins.str] snapshot_type: 快照类型，取值说明如下：user：查询手动快照。auto：查询自动快照。share：查询共享快照。默认查询所有快照。
        :param pulumi.Input[builtins.str] status: 快照状态，取值说明如下：available：可用。creating：创建中。rollbacking：回滚中。deleted：已删除。failed：错误。
        :param pulumi.Input[builtins.str] volume_id: 快照相关的云盘ID。
        :param pulumi.Input[builtins.str] volume_kind: 云盘种类，取值说明如下：system：系统盘。data：数据盘。
        :param pulumi.Input[builtins.str] volume_name: 云盘名称。
        :param pulumi.Input[builtins.int] volume_size: 云盘大小，单位为GiB。
        :param pulumi.Input[builtins.str] volume_status: 云盘状态，取值说明如下：available：可用, attaching：挂载中, attached：已挂载, detaching：卸载中, creating：创建中, deleting：删除中, error：错误, extending：扩容中, ""：云盘被删除。
        :param pulumi.Input[builtins.str] volume_type: 云盘类型，取值说明如下：ESSD*PL0：极速型SSD云盘，PL0规格。ESSD*FlexPL：极速型SSD云盘，FlexPL规格。TSSD_TL0：吞吐型SSD云盘
        :param pulumi.Input[builtins.str] zone_id: 快照所在的可用区ID。
        """
        if creation_time is not None:
            pulumi.set(__self__, "creation_time", creation_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if image_id is not None:
            pulumi.set(__self__, "image_id", image_id)
        if instant_access is not None:
            pulumi.set(__self__, "instant_access", instant_access)
        if progress is not None:
            pulumi.set(__self__, "progress", progress)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if retention_days is not None:
            pulumi.set(__self__, "retention_days", retention_days)
        if shared is not None:
            pulumi.set(__self__, "shared", shared)
        if snapshot_group_id is not None:
            pulumi.set(__self__, "snapshot_group_id", snapshot_group_id)
        if snapshot_id is not None:
            pulumi.set(__self__, "snapshot_id", snapshot_id)
        if snapshot_name is not None:
            pulumi.set(__self__, "snapshot_name", snapshot_name)
        if snapshot_type is not None:
            pulumi.set(__self__, "snapshot_type", snapshot_type)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if volume_id is not None:
            pulumi.set(__self__, "volume_id", volume_id)
        if volume_kind is not None:
            pulumi.set(__self__, "volume_kind", volume_kind)
        if volume_name is not None:
            pulumi.set(__self__, "volume_name", volume_name)
        if volume_size is not None:
            pulumi.set(__self__, "volume_size", volume_size)
        if volume_status is not None:
            pulumi.set(__self__, "volume_status", volume_status)
        if volume_type is not None:
            pulumi.set(__self__, "volume_type", volume_type)
        if zone_id is not None:
            pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter(name="creationTime")
    def creation_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        快照创建时间。
        """
        return pulumi.get(self, "creation_time")

    @creation_time.setter
    def creation_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "creation_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        快照描述信息，默认为空，长度限制为0~255个字符。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="imageId")
    def image_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        镜像ID
        """
        return pulumi.get(self, "image_id")

    @image_id.setter
    def image_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "image_id", value)

    @property
    @pulumi.getter(name="instantAccess")
    def instant_access(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        快照是否开启极速可用能力，取值说明如下：true：已开启极速可用能力。false：未开启极速可用能力。
        """
        return pulumi.get(self, "instant_access")

    @instant_access.setter
    def instant_access(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "instant_access", value)

    @property
    @pulumi.getter
    def progress(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        快照转储进度。
        """
        return pulumi.get(self, "progress")

    @progress.setter
    def progress(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "progress", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        快照所要加入的Project（项目）名称。注意快照不会继承云盘的项目，即快照与云盘可以所属不同的项目。如果您在创建快照时未设置ProjectName，快照会默认加入default项目。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="retentionDays")
    def retention_days(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        快照保留时间，单位为天，取值说明如下：空：永久保留快照 。1~65536：指定保存天数。默认为空，即默认永久保留快照。说明快照保留时间从快照创建时刻开始计算。
        """
        return pulumi.get(self, "retention_days")

    @retention_days.setter
    def retention_days(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "retention_days", value)

    @property
    @pulumi.getter
    def shared(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        快照是否共享。
        """
        return pulumi.get(self, "shared")

    @shared.setter
    def shared(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "shared", value)

    @property
    @pulumi.getter(name="snapshotGroupId")
    def snapshot_group_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        快照一致性组ID。
        """
        return pulumi.get(self, "snapshot_group_id")

    @snapshot_group_id.setter
    def snapshot_group_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "snapshot_group_id", value)

    @property
    @pulumi.getter(name="snapshotId")
    def snapshot_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        快照ID。
        """
        return pulumi.get(self, "snapshot_id")

    @snapshot_id.setter
    def snapshot_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "snapshot_id", value)

    @property
    @pulumi.getter(name="snapshotName")
    def snapshot_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        创建的快照名称。命名规范如下：长度限制为1~128个字符。只能包含中文、字母、数字、下划线（_）、中划线（-）和英文句号（.）。为防止和自动快照的名称冲突，不能以“auto”开头。
        """
        return pulumi.get(self, "snapshot_name")

    @snapshot_name.setter
    def snapshot_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "snapshot_name", value)

    @property
    @pulumi.getter(name="snapshotType")
    def snapshot_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        快照类型，取值说明如下：user：查询手动快照。auto：查询自动快照。share：查询共享快照。默认查询所有快照。
        """
        return pulumi.get(self, "snapshot_type")

    @snapshot_type.setter
    def snapshot_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "snapshot_type", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        快照状态，取值说明如下：available：可用。creating：创建中。rollbacking：回滚中。deleted：已删除。failed：错误。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SnapshotTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SnapshotTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="volumeId")
    def volume_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        快照相关的云盘ID。
        """
        return pulumi.get(self, "volume_id")

    @volume_id.setter
    def volume_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "volume_id", value)

    @property
    @pulumi.getter(name="volumeKind")
    def volume_kind(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        云盘种类，取值说明如下：system：系统盘。data：数据盘。
        """
        return pulumi.get(self, "volume_kind")

    @volume_kind.setter
    def volume_kind(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "volume_kind", value)

    @property
    @pulumi.getter(name="volumeName")
    def volume_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        云盘名称。
        """
        return pulumi.get(self, "volume_name")

    @volume_name.setter
    def volume_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "volume_name", value)

    @property
    @pulumi.getter(name="volumeSize")
    def volume_size(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        云盘大小，单位为GiB。
        """
        return pulumi.get(self, "volume_size")

    @volume_size.setter
    def volume_size(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "volume_size", value)

    @property
    @pulumi.getter(name="volumeStatus")
    def volume_status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        云盘状态，取值说明如下：available：可用, attaching：挂载中, attached：已挂载, detaching：卸载中, creating：创建中, deleting：删除中, error：错误, extending：扩容中, ""：云盘被删除。
        """
        return pulumi.get(self, "volume_status")

    @volume_status.setter
    def volume_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "volume_status", value)

    @property
    @pulumi.getter(name="volumeType")
    def volume_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        云盘类型，取值说明如下：ESSD*PL0：极速型SSD云盘，PL0规格。ESSD*FlexPL：极速型SSD云盘，FlexPL规格。TSSD_TL0：吞吐型SSD云盘
        """
        return pulumi.get(self, "volume_type")

    @volume_type.setter
    def volume_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "volume_type", value)

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        快照所在的可用区ID。
        """
        return pulumi.get(self, "zone_id")

    @zone_id.setter
    def zone_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "zone_id", value)


@pulumi.type_token("bytepluscc:storageebs/snapshot:Snapshot")
class Snapshot(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 retention_days: Optional[pulumi.Input[builtins.int]] = None,
                 snapshot_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SnapshotTagArgs', 'SnapshotTagArgsDict']]]]] = None,
                 volume_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        快照是一种备份方式，每个快照都是云盘数据在某个时间点的备份文件。当数据丢失或故障时，您可以通过快照回滚云盘数据，找回丢失的数据。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        storage_ebs_snapshot_demo = bytepluscc.storageebs.Snapshot("StorageEBSSnapshotDemo",
            volume_id="vol-3wt6pip1dy3qu*****",
            snapshot_name="StorageEBSSnapshotDemo",
            description="StorageEBSSnapshotDemo description",
            project_name="default",
            tags=[{
                "key": "env",
                "value": "test",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:storageebs/snapshot:Snapshot example "snapshot_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: 快照描述信息，默认为空，长度限制为0~255个字符。
        :param pulumi.Input[builtins.str] project_name: 快照所要加入的Project（项目）名称。注意快照不会继承云盘的项目，即快照与云盘可以所属不同的项目。如果您在创建快照时未设置ProjectName，快照会默认加入default项目。
        :param pulumi.Input[builtins.int] retention_days: 快照保留时间，单位为天，取值说明如下：空：永久保留快照 。1~65536：指定保存天数。默认为空，即默认永久保留快照。说明快照保留时间从快照创建时刻开始计算。
        :param pulumi.Input[builtins.str] snapshot_name: 创建的快照名称。命名规范如下：长度限制为1~128个字符。只能包含中文、字母、数字、下划线（_）、中划线（-）和英文句号（.）。为防止和自动快照的名称冲突，不能以“auto”开头。
        :param pulumi.Input[builtins.str] volume_id: 快照相关的云盘ID。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SnapshotArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        快照是一种备份方式，每个快照都是云盘数据在某个时间点的备份文件。当数据丢失或故障时，您可以通过快照回滚云盘数据，找回丢失的数据。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        storage_ebs_snapshot_demo = bytepluscc.storageebs.Snapshot("StorageEBSSnapshotDemo",
            volume_id="vol-3wt6pip1dy3qu*****",
            snapshot_name="StorageEBSSnapshotDemo",
            description="StorageEBSSnapshotDemo description",
            project_name="default",
            tags=[{
                "key": "env",
                "value": "test",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:storageebs/snapshot:Snapshot example "snapshot_id"
        ```

        :param str resource_name: The name of the resource.
        :param SnapshotArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SnapshotArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 retention_days: Optional[pulumi.Input[builtins.int]] = None,
                 snapshot_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SnapshotTagArgs', 'SnapshotTagArgsDict']]]]] = None,
                 volume_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SnapshotArgs.__new__(SnapshotArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["project_name"] = project_name
            __props__.__dict__["retention_days"] = retention_days
            if snapshot_name is None and not opts.urn:
                raise TypeError("Missing required property 'snapshot_name'")
            __props__.__dict__["snapshot_name"] = snapshot_name
            __props__.__dict__["tags"] = tags
            if volume_id is None and not opts.urn:
                raise TypeError("Missing required property 'volume_id'")
            __props__.__dict__["volume_id"] = volume_id
            __props__.__dict__["creation_time"] = None
            __props__.__dict__["image_id"] = None
            __props__.__dict__["instant_access"] = None
            __props__.__dict__["progress"] = None
            __props__.__dict__["shared"] = None
            __props__.__dict__["snapshot_group_id"] = None
            __props__.__dict__["snapshot_id"] = None
            __props__.__dict__["snapshot_type"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["volume_kind"] = None
            __props__.__dict__["volume_name"] = None
            __props__.__dict__["volume_size"] = None
            __props__.__dict__["volume_status"] = None
            __props__.__dict__["volume_type"] = None
            __props__.__dict__["zone_id"] = None
        super(Snapshot, __self__).__init__(
            'bytepluscc:storageebs/snapshot:Snapshot',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            creation_time: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            image_id: Optional[pulumi.Input[builtins.str]] = None,
            instant_access: Optional[pulumi.Input[builtins.bool]] = None,
            progress: Optional[pulumi.Input[builtins.int]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            retention_days: Optional[pulumi.Input[builtins.int]] = None,
            shared: Optional[pulumi.Input[builtins.bool]] = None,
            snapshot_group_id: Optional[pulumi.Input[builtins.str]] = None,
            snapshot_id: Optional[pulumi.Input[builtins.str]] = None,
            snapshot_name: Optional[pulumi.Input[builtins.str]] = None,
            snapshot_type: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SnapshotTagArgs', 'SnapshotTagArgsDict']]]]] = None,
            volume_id: Optional[pulumi.Input[builtins.str]] = None,
            volume_kind: Optional[pulumi.Input[builtins.str]] = None,
            volume_name: Optional[pulumi.Input[builtins.str]] = None,
            volume_size: Optional[pulumi.Input[builtins.int]] = None,
            volume_status: Optional[pulumi.Input[builtins.str]] = None,
            volume_type: Optional[pulumi.Input[builtins.str]] = None,
            zone_id: Optional[pulumi.Input[builtins.str]] = None) -> 'Snapshot':
        """
        Get an existing Snapshot resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] creation_time: 快照创建时间。
        :param pulumi.Input[builtins.str] description: 快照描述信息，默认为空，长度限制为0~255个字符。
        :param pulumi.Input[builtins.str] image_id: 镜像ID
        :param pulumi.Input[builtins.bool] instant_access: 快照是否开启极速可用能力，取值说明如下：true：已开启极速可用能力。false：未开启极速可用能力。
        :param pulumi.Input[builtins.int] progress: 快照转储进度。
        :param pulumi.Input[builtins.str] project_name: 快照所要加入的Project（项目）名称。注意快照不会继承云盘的项目，即快照与云盘可以所属不同的项目。如果您在创建快照时未设置ProjectName，快照会默认加入default项目。
        :param pulumi.Input[builtins.int] retention_days: 快照保留时间，单位为天，取值说明如下：空：永久保留快照 。1~65536：指定保存天数。默认为空，即默认永久保留快照。说明快照保留时间从快照创建时刻开始计算。
        :param pulumi.Input[builtins.bool] shared: 快照是否共享。
        :param pulumi.Input[builtins.str] snapshot_group_id: 快照一致性组ID。
        :param pulumi.Input[builtins.str] snapshot_id: 快照ID。
        :param pulumi.Input[builtins.str] snapshot_name: 创建的快照名称。命名规范如下：长度限制为1~128个字符。只能包含中文、字母、数字、下划线（_）、中划线（-）和英文句号（.）。为防止和自动快照的名称冲突，不能以“auto”开头。
        :param pulumi.Input[builtins.str] snapshot_type: 快照类型，取值说明如下：user：查询手动快照。auto：查询自动快照。share：查询共享快照。默认查询所有快照。
        :param pulumi.Input[builtins.str] status: 快照状态，取值说明如下：available：可用。creating：创建中。rollbacking：回滚中。deleted：已删除。failed：错误。
        :param pulumi.Input[builtins.str] volume_id: 快照相关的云盘ID。
        :param pulumi.Input[builtins.str] volume_kind: 云盘种类，取值说明如下：system：系统盘。data：数据盘。
        :param pulumi.Input[builtins.str] volume_name: 云盘名称。
        :param pulumi.Input[builtins.int] volume_size: 云盘大小，单位为GiB。
        :param pulumi.Input[builtins.str] volume_status: 云盘状态，取值说明如下：available：可用, attaching：挂载中, attached：已挂载, detaching：卸载中, creating：创建中, deleting：删除中, error：错误, extending：扩容中, ""：云盘被删除。
        :param pulumi.Input[builtins.str] volume_type: 云盘类型，取值说明如下：ESSD*PL0：极速型SSD云盘，PL0规格。ESSD*FlexPL：极速型SSD云盘，FlexPL规格。TSSD_TL0：吞吐型SSD云盘
        :param pulumi.Input[builtins.str] zone_id: 快照所在的可用区ID。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SnapshotState.__new__(_SnapshotState)

        __props__.__dict__["creation_time"] = creation_time
        __props__.__dict__["description"] = description
        __props__.__dict__["image_id"] = image_id
        __props__.__dict__["instant_access"] = instant_access
        __props__.__dict__["progress"] = progress
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["retention_days"] = retention_days
        __props__.__dict__["shared"] = shared
        __props__.__dict__["snapshot_group_id"] = snapshot_group_id
        __props__.__dict__["snapshot_id"] = snapshot_id
        __props__.__dict__["snapshot_name"] = snapshot_name
        __props__.__dict__["snapshot_type"] = snapshot_type
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["volume_id"] = volume_id
        __props__.__dict__["volume_kind"] = volume_kind
        __props__.__dict__["volume_name"] = volume_name
        __props__.__dict__["volume_size"] = volume_size
        __props__.__dict__["volume_status"] = volume_status
        __props__.__dict__["volume_type"] = volume_type
        __props__.__dict__["zone_id"] = zone_id
        return Snapshot(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="creationTime")
    def creation_time(self) -> pulumi.Output[builtins.str]:
        """
        快照创建时间。
        """
        return pulumi.get(self, "creation_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        快照描述信息，默认为空，长度限制为0~255个字符。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="imageId")
    def image_id(self) -> pulumi.Output[builtins.str]:
        """
        镜像ID
        """
        return pulumi.get(self, "image_id")

    @property
    @pulumi.getter(name="instantAccess")
    def instant_access(self) -> pulumi.Output[builtins.bool]:
        """
        快照是否开启极速可用能力，取值说明如下：true：已开启极速可用能力。false：未开启极速可用能力。
        """
        return pulumi.get(self, "instant_access")

    @property
    @pulumi.getter
    def progress(self) -> pulumi.Output[builtins.int]:
        """
        快照转储进度。
        """
        return pulumi.get(self, "progress")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        快照所要加入的Project（项目）名称。注意快照不会继承云盘的项目，即快照与云盘可以所属不同的项目。如果您在创建快照时未设置ProjectName，快照会默认加入default项目。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="retentionDays")
    def retention_days(self) -> pulumi.Output[builtins.int]:
        """
        快照保留时间，单位为天，取值说明如下：空：永久保留快照 。1~65536：指定保存天数。默认为空，即默认永久保留快照。说明快照保留时间从快照创建时刻开始计算。
        """
        return pulumi.get(self, "retention_days")

    @property
    @pulumi.getter
    def shared(self) -> pulumi.Output[builtins.bool]:
        """
        快照是否共享。
        """
        return pulumi.get(self, "shared")

    @property
    @pulumi.getter(name="snapshotGroupId")
    def snapshot_group_id(self) -> pulumi.Output[builtins.str]:
        """
        快照一致性组ID。
        """
        return pulumi.get(self, "snapshot_group_id")

    @property
    @pulumi.getter(name="snapshotId")
    def snapshot_id(self) -> pulumi.Output[builtins.str]:
        """
        快照ID。
        """
        return pulumi.get(self, "snapshot_id")

    @property
    @pulumi.getter(name="snapshotName")
    def snapshot_name(self) -> pulumi.Output[builtins.str]:
        """
        创建的快照名称。命名规范如下：长度限制为1~128个字符。只能包含中文、字母、数字、下划线（_）、中划线（-）和英文句号（.）。为防止和自动快照的名称冲突，不能以“auto”开头。
        """
        return pulumi.get(self, "snapshot_name")

    @property
    @pulumi.getter(name="snapshotType")
    def snapshot_type(self) -> pulumi.Output[builtins.str]:
        """
        快照类型，取值说明如下：user：查询手动快照。auto：查询自动快照。share：查询共享快照。默认查询所有快照。
        """
        return pulumi.get(self, "snapshot_type")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        快照状态，取值说明如下：available：可用。creating：创建中。rollbacking：回滚中。deleted：已删除。failed：错误。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.SnapshotTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="volumeId")
    def volume_id(self) -> pulumi.Output[builtins.str]:
        """
        快照相关的云盘ID。
        """
        return pulumi.get(self, "volume_id")

    @property
    @pulumi.getter(name="volumeKind")
    def volume_kind(self) -> pulumi.Output[builtins.str]:
        """
        云盘种类，取值说明如下：system：系统盘。data：数据盘。
        """
        return pulumi.get(self, "volume_kind")

    @property
    @pulumi.getter(name="volumeName")
    def volume_name(self) -> pulumi.Output[builtins.str]:
        """
        云盘名称。
        """
        return pulumi.get(self, "volume_name")

    @property
    @pulumi.getter(name="volumeSize")
    def volume_size(self) -> pulumi.Output[builtins.int]:
        """
        云盘大小，单位为GiB。
        """
        return pulumi.get(self, "volume_size")

    @property
    @pulumi.getter(name="volumeStatus")
    def volume_status(self) -> pulumi.Output[builtins.str]:
        """
        云盘状态，取值说明如下：available：可用, attaching：挂载中, attached：已挂载, detaching：卸载中, creating：创建中, deleting：删除中, error：错误, extending：扩容中, ""：云盘被删除。
        """
        return pulumi.get(self, "volume_status")

    @property
    @pulumi.getter(name="volumeType")
    def volume_type(self) -> pulumi.Output[builtins.str]:
        """
        云盘类型，取值说明如下：ESSD*PL0：极速型SSD云盘，PL0规格。ESSD*FlexPL：极速型SSD云盘，FlexPL规格。TSSD_TL0：吞吐型SSD云盘
        """
        return pulumi.get(self, "volume_type")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> pulumi.Output[builtins.str]:
        """
        快照所在的可用区ID。
        """
        return pulumi.get(self, "zone_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['InstanceArgs', 'Instance']

@pulumi.input_type
class InstanceArgs:
    def __init__(__self__, *,
                 billing_type: pulumi.Input[builtins.str],
                 name: pulumi.Input[builtins.str],
                 project_name: pulumi.Input[builtins.str],
                 security_group_id_lists: pulumi.Input[Sequence[pulumi.Input[builtins.str]]],
                 specification: pulumi.Input[builtins.str],
                 subnet_id_lists: pulumi.Input[Sequence[pulumi.Input[builtins.str]]],
                 vpc_id: pulumi.Input[builtins.str],
                 zone_id_lists: pulumi.Input[Sequence[pulumi.Input[builtins.str]]],
                 auto_renew: Optional[pulumi.Input[builtins.str]] = None,
                 billing_period: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 eip_id: Optional[pulumi.Input[builtins.str]] = None,
                 endpoints: Optional[pulumi.Input['InstanceEndpointsArgs']] = None,
                 message_retention: Optional[pulumi.Input[builtins.int]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceTagArgs']]]] = None,
                 times: Optional[pulumi.Input[builtins.int]] = None):
        """
        The set of arguments for constructing a Instance resource.
        :param pulumi.Input[builtins.str] billing_type: 实例的计费方式，取值如下：POST：按量计费。MIX：包年包月。
        :param pulumi.Input[builtins.str] name: 自定设置 BMQ 实例的名称，约束限制如下：由小写字母、数字和中划线（-）组成。长度为 1~64 字符。
        :param pulumi.Input[builtins.str] project_name: 实例所属项目名称。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] security_group_id_lists: 实例使用安全组列表。
        :param pulumi.Input[builtins.str] specification: 实例规格。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] subnet_id_lists: 实例使用的子网列表。
        :param pulumi.Input[builtins.str] vpc_id: 实例所在VPC ID。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] zone_id_lists: 实例所在可用区列表。
        :param pulumi.Input[builtins.str] auto_renew: 是否开启自动续费，取值如下：true：开启自动续费。false：关闭自动续费。
        :param pulumi.Input[builtins.str] billing_period: 购买时长的单位，取值如下：MONTHLY：按月购买。YEARLY：按年购买。
        :param pulumi.Input[builtins.str] description: 实例的描述语句。
        :param pulumi.Input[builtins.str] eip_id: 实例是否开启公网访问。如果需要开启公网访问，请配置相同地域的公网 IP 的 ID。
        :param pulumi.Input['InstanceEndpointsArgs'] endpoints: 实例所有接入点响应数据。
        :param pulumi.Input[builtins.int] message_retention: 实例下所有 Topic 的消息保留时长，单位为小时。
        :param pulumi.Input[builtins.int] times: 包年包月类型实例的购买时长，单位为月。
        """
        pulumi.set(__self__, "billing_type", billing_type)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "project_name", project_name)
        pulumi.set(__self__, "security_group_id_lists", security_group_id_lists)
        pulumi.set(__self__, "specification", specification)
        pulumi.set(__self__, "subnet_id_lists", subnet_id_lists)
        pulumi.set(__self__, "vpc_id", vpc_id)
        pulumi.set(__self__, "zone_id_lists", zone_id_lists)
        if auto_renew is not None:
            pulumi.set(__self__, "auto_renew", auto_renew)
        if billing_period is not None:
            pulumi.set(__self__, "billing_period", billing_period)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if eip_id is not None:
            pulumi.set(__self__, "eip_id", eip_id)
        if endpoints is not None:
            pulumi.set(__self__, "endpoints", endpoints)
        if message_retention is not None:
            pulumi.set(__self__, "message_retention", message_retention)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if times is not None:
            pulumi.set(__self__, "times", times)

    @property
    @pulumi.getter(name="billingType")
    def billing_type(self) -> pulumi.Input[builtins.str]:
        """
        实例的计费方式，取值如下：POST：按量计费。MIX：包年包月。
        """
        return pulumi.get(self, "billing_type")

    @billing_type.setter
    def billing_type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "billing_type", value)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[builtins.str]:
        """
        自定设置 BMQ 实例的名称，约束限制如下：由小写字母、数字和中划线（-）组成。长度为 1~64 字符。
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Input[builtins.str]:
        """
        实例所属项目名称。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="securityGroupIdLists")
    def security_group_id_lists(self) -> pulumi.Input[Sequence[pulumi.Input[builtins.str]]]:
        """
        实例使用安全组列表。
        """
        return pulumi.get(self, "security_group_id_lists")

    @security_group_id_lists.setter
    def security_group_id_lists(self, value: pulumi.Input[Sequence[pulumi.Input[builtins.str]]]):
        pulumi.set(self, "security_group_id_lists", value)

    @property
    @pulumi.getter
    def specification(self) -> pulumi.Input[builtins.str]:
        """
        实例规格。
        """
        return pulumi.get(self, "specification")

    @specification.setter
    def specification(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "specification", value)

    @property
    @pulumi.getter(name="subnetIdLists")
    def subnet_id_lists(self) -> pulumi.Input[Sequence[pulumi.Input[builtins.str]]]:
        """
        实例使用的子网列表。
        """
        return pulumi.get(self, "subnet_id_lists")

    @subnet_id_lists.setter
    def subnet_id_lists(self, value: pulumi.Input[Sequence[pulumi.Input[builtins.str]]]):
        pulumi.set(self, "subnet_id_lists", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Input[builtins.str]:
        """
        实例所在VPC ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="zoneIdLists")
    def zone_id_lists(self) -> pulumi.Input[Sequence[pulumi.Input[builtins.str]]]:
        """
        实例所在可用区列表。
        """
        return pulumi.get(self, "zone_id_lists")

    @zone_id_lists.setter
    def zone_id_lists(self, value: pulumi.Input[Sequence[pulumi.Input[builtins.str]]]):
        pulumi.set(self, "zone_id_lists", value)

    @property
    @pulumi.getter(name="autoRenew")
    def auto_renew(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        是否开启自动续费，取值如下：true：开启自动续费。false：关闭自动续费。
        """
        return pulumi.get(self, "auto_renew")

    @auto_renew.setter
    def auto_renew(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "auto_renew", value)

    @property
    @pulumi.getter(name="billingPeriod")
    def billing_period(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        购买时长的单位，取值如下：MONTHLY：按月购买。YEARLY：按年购买。
        """
        return pulumi.get(self, "billing_period")

    @billing_period.setter
    def billing_period(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "billing_period", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的描述语句。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="eipId")
    def eip_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例是否开启公网访问。如果需要开启公网访问，请配置相同地域的公网 IP 的 ID。
        """
        return pulumi.get(self, "eip_id")

    @eip_id.setter
    def eip_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "eip_id", value)

    @property
    @pulumi.getter
    def endpoints(self) -> Optional[pulumi.Input['InstanceEndpointsArgs']]:
        """
        实例所有接入点响应数据。
        """
        return pulumi.get(self, "endpoints")

    @endpoints.setter
    def endpoints(self, value: Optional[pulumi.Input['InstanceEndpointsArgs']]):
        pulumi.set(self, "endpoints", value)

    @property
    @pulumi.getter(name="messageRetention")
    def message_retention(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        实例下所有 Topic 的消息保留时长，单位为小时。
        """
        return pulumi.get(self, "message_retention")

    @message_retention.setter
    def message_retention(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "message_retention", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['InstanceTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def times(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        包年包月类型实例的购买时长，单位为月。
        """
        return pulumi.get(self, "times")

    @times.setter
    def times(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "times", value)


@pulumi.input_type
class _InstanceState:
    def __init__(__self__, *,
                 auto_renew: Optional[pulumi.Input[builtins.str]] = None,
                 billing_period: Optional[pulumi.Input[builtins.str]] = None,
                 billing_type: Optional[pulumi.Input[builtins.str]] = None,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 eip_id: Optional[pulumi.Input[builtins.str]] = None,
                 endpoints: Optional[pulumi.Input['InstanceEndpointsArgs']] = None,
                 expiration_time: Optional[pulumi.Input[builtins.str]] = None,
                 group_limit: Optional[pulumi.Input[builtins.int]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 message_retention: Optional[pulumi.Input[builtins.int]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 partition_limit: Optional[pulumi.Input[builtins.int]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 resource_tags: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceResourceTagArgs']]]] = None,
                 resources: Optional[pulumi.Input['InstanceResourcesArgs']] = None,
                 security_group_id_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 specification: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 subnet_id_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceTagArgs']]]] = None,
                 times: Optional[pulumi.Input[builtins.int]] = None,
                 topic_limit: Optional[pulumi.Input[builtins.int]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 zone_id_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering Instance resources.
        :param pulumi.Input[builtins.str] auto_renew: 是否开启自动续费，取值如下：true：开启自动续费。false：关闭自动续费。
        :param pulumi.Input[builtins.str] billing_period: 购买时长的单位，取值如下：MONTHLY：按月购买。YEARLY：按年购买。
        :param pulumi.Input[builtins.str] billing_type: 实例的计费方式，取值如下：POST：按量计费。MIX：包年包月。
        :param pulumi.Input[builtins.str] created_time: 实例的创建时间。
        :param pulumi.Input[builtins.str] description: 实例的描述语句。
        :param pulumi.Input[builtins.str] eip_id: 实例是否开启公网访问。如果需要开启公网访问，请配置相同地域的公网 IP 的 ID。
        :param pulumi.Input['InstanceEndpointsArgs'] endpoints: 实例所有接入点响应数据。
        :param pulumi.Input[builtins.str] expiration_time: 实例过期时间。
        :param pulumi.Input[builtins.int] group_limit: 实例消费组数量上限。
        :param pulumi.Input[builtins.str] instance_id: 实例ID。
        :param pulumi.Input[builtins.int] message_retention: 实例下所有 Topic 的消息保留时长，单位为小时。
        :param pulumi.Input[builtins.str] name: 自定设置 BMQ 实例的名称，约束限制如下：由小写字母、数字和中划线（-）组成。长度为 1~64 字符。
        :param pulumi.Input[builtins.int] partition_limit: 实例分区数量上限。
        :param pulumi.Input[builtins.str] project_name: 实例所属项目名称。
        :param pulumi.Input['InstanceResourcesArgs'] resources: 实例资源统计响应数据。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] security_group_id_lists: 实例使用安全组列表。
        :param pulumi.Input[builtins.str] specification: 实例规格。
        :param pulumi.Input[builtins.str] status: 实例的状态。取值如下：INITIALIZING：初始化中，INITIALIZATION*FAILED：初始化失败，RUNNING：运行中，MODIFYING：更新中，MODIFY*FAILED：更新失败，RELEASING：释放中，STOPPING：停止中，STOPPED：停止，RECOVERING：恢复中，EXCEPTION：异常，CAPACITY*EXPAXION*FAILED：扩容失败，EXPANDING*CAPACITY：扩容中，CANCEL*EXPANDING_CAPACITY：扩容取消中，RESTARTING：重启中，UNPAID：未支付
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] subnet_id_lists: 实例使用的子网列表。
        :param pulumi.Input[builtins.int] times: 包年包月类型实例的购买时长，单位为月。
        :param pulumi.Input[builtins.int] topic_limit: 实例Topic数量上限。
        :param pulumi.Input[builtins.str] vpc_id: 实例所在VPC ID。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] zone_id_lists: 实例所在可用区列表。
        """
        if auto_renew is not None:
            pulumi.set(__self__, "auto_renew", auto_renew)
        if billing_period is not None:
            pulumi.set(__self__, "billing_period", billing_period)
        if billing_type is not None:
            pulumi.set(__self__, "billing_type", billing_type)
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if eip_id is not None:
            pulumi.set(__self__, "eip_id", eip_id)
        if endpoints is not None:
            pulumi.set(__self__, "endpoints", endpoints)
        if expiration_time is not None:
            pulumi.set(__self__, "expiration_time", expiration_time)
        if group_limit is not None:
            pulumi.set(__self__, "group_limit", group_limit)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if message_retention is not None:
            pulumi.set(__self__, "message_retention", message_retention)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if partition_limit is not None:
            pulumi.set(__self__, "partition_limit", partition_limit)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if resource_tags is not None:
            pulumi.set(__self__, "resource_tags", resource_tags)
        if resources is not None:
            pulumi.set(__self__, "resources", resources)
        if security_group_id_lists is not None:
            pulumi.set(__self__, "security_group_id_lists", security_group_id_lists)
        if specification is not None:
            pulumi.set(__self__, "specification", specification)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if subnet_id_lists is not None:
            pulumi.set(__self__, "subnet_id_lists", subnet_id_lists)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if times is not None:
            pulumi.set(__self__, "times", times)
        if topic_limit is not None:
            pulumi.set(__self__, "topic_limit", topic_limit)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)
        if zone_id_lists is not None:
            pulumi.set(__self__, "zone_id_lists", zone_id_lists)

    @property
    @pulumi.getter(name="autoRenew")
    def auto_renew(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        是否开启自动续费，取值如下：true：开启自动续费。false：关闭自动续费。
        """
        return pulumi.get(self, "auto_renew")

    @auto_renew.setter
    def auto_renew(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "auto_renew", value)

    @property
    @pulumi.getter(name="billingPeriod")
    def billing_period(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        购买时长的单位，取值如下：MONTHLY：按月购买。YEARLY：按年购买。
        """
        return pulumi.get(self, "billing_period")

    @billing_period.setter
    def billing_period(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "billing_period", value)

    @property
    @pulumi.getter(name="billingType")
    def billing_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的计费方式，取值如下：POST：按量计费。MIX：包年包月。
        """
        return pulumi.get(self, "billing_type")

    @billing_type.setter
    def billing_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "billing_type", value)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的创建时间。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的描述语句。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="eipId")
    def eip_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例是否开启公网访问。如果需要开启公网访问，请配置相同地域的公网 IP 的 ID。
        """
        return pulumi.get(self, "eip_id")

    @eip_id.setter
    def eip_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "eip_id", value)

    @property
    @pulumi.getter
    def endpoints(self) -> Optional[pulumi.Input['InstanceEndpointsArgs']]:
        """
        实例所有接入点响应数据。
        """
        return pulumi.get(self, "endpoints")

    @endpoints.setter
    def endpoints(self, value: Optional[pulumi.Input['InstanceEndpointsArgs']]):
        pulumi.set(self, "endpoints", value)

    @property
    @pulumi.getter(name="expirationTime")
    def expiration_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例过期时间。
        """
        return pulumi.get(self, "expiration_time")

    @expiration_time.setter
    def expiration_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "expiration_time", value)

    @property
    @pulumi.getter(name="groupLimit")
    def group_limit(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        实例消费组数量上限。
        """
        return pulumi.get(self, "group_limit")

    @group_limit.setter
    def group_limit(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "group_limit", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例ID。
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="messageRetention")
    def message_retention(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        实例下所有 Topic 的消息保留时长，单位为小时。
        """
        return pulumi.get(self, "message_retention")

    @message_retention.setter
    def message_retention(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "message_retention", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        自定设置 BMQ 实例的名称，约束限制如下：由小写字母、数字和中划线（-）组成。长度为 1~64 字符。
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="partitionLimit")
    def partition_limit(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        实例分区数量上限。
        """
        return pulumi.get(self, "partition_limit")

    @partition_limit.setter
    def partition_limit(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "partition_limit", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例所属项目名称。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="resourceTags")
    def resource_tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['InstanceResourceTagArgs']]]]:
        return pulumi.get(self, "resource_tags")

    @resource_tags.setter
    def resource_tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceResourceTagArgs']]]]):
        pulumi.set(self, "resource_tags", value)

    @property
    @pulumi.getter
    def resources(self) -> Optional[pulumi.Input['InstanceResourcesArgs']]:
        """
        实例资源统计响应数据。
        """
        return pulumi.get(self, "resources")

    @resources.setter
    def resources(self, value: Optional[pulumi.Input['InstanceResourcesArgs']]):
        pulumi.set(self, "resources", value)

    @property
    @pulumi.getter(name="securityGroupIdLists")
    def security_group_id_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        实例使用安全组列表。
        """
        return pulumi.get(self, "security_group_id_lists")

    @security_group_id_lists.setter
    def security_group_id_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "security_group_id_lists", value)

    @property
    @pulumi.getter
    def specification(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例规格。
        """
        return pulumi.get(self, "specification")

    @specification.setter
    def specification(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "specification", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的状态。取值如下：INITIALIZING：初始化中，INITIALIZATION*FAILED：初始化失败，RUNNING：运行中，MODIFYING：更新中，MODIFY*FAILED：更新失败，RELEASING：释放中，STOPPING：停止中，STOPPED：停止，RECOVERING：恢复中，EXCEPTION：异常，CAPACITY*EXPAXION*FAILED：扩容失败，EXPANDING*CAPACITY：扩容中，CANCEL*EXPANDING_CAPACITY：扩容取消中，RESTARTING：重启中，UNPAID：未支付
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="subnetIdLists")
    def subnet_id_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        实例使用的子网列表。
        """
        return pulumi.get(self, "subnet_id_lists")

    @subnet_id_lists.setter
    def subnet_id_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "subnet_id_lists", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['InstanceTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def times(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        包年包月类型实例的购买时长，单位为月。
        """
        return pulumi.get(self, "times")

    @times.setter
    def times(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "times", value)

    @property
    @pulumi.getter(name="topicLimit")
    def topic_limit(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        实例Topic数量上限。
        """
        return pulumi.get(self, "topic_limit")

    @topic_limit.setter
    def topic_limit(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "topic_limit", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例所在VPC ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="zoneIdLists")
    def zone_id_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        实例所在可用区列表。
        """
        return pulumi.get(self, "zone_id_lists")

    @zone_id_lists.setter
    def zone_id_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "zone_id_lists", value)


@pulumi.type_token("bytepluscc:bmq/instance:Instance")
class Instance(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auto_renew: Optional[pulumi.Input[builtins.str]] = None,
                 billing_period: Optional[pulumi.Input[builtins.str]] = None,
                 billing_type: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 eip_id: Optional[pulumi.Input[builtins.str]] = None,
                 endpoints: Optional[pulumi.Input[Union['InstanceEndpointsArgs', 'InstanceEndpointsArgsDict']]] = None,
                 message_retention: Optional[pulumi.Input[builtins.int]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 security_group_id_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 specification: Optional[pulumi.Input[builtins.str]] = None,
                 subnet_id_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InstanceTagArgs', 'InstanceTagArgsDict']]]]] = None,
                 times: Optional[pulumi.Input[builtins.int]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 zone_id_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        """
        云原生消息引擎 100% 兼容 Apache Kafka 协议，基于云原生的全托管、高吞吐、低时延、高可用、高可扩展性、高稳定性的分布式消息引擎服务，支持灵活动态扩缩容和流批一体计算，提供企业级大数据量级的实时流数据处理能力，帮助您构建数据处理的“中枢神经系统”，广泛应用于日志收集、数据聚合、离线数据分析等业务场景。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        b_mq_instance_demo = bytepluscc.bmq.Instance("BMQInstanceDemo",
            name="BMQInstanceDemo",
            billing_type="POST",
            project_name="default",
            specification="bmq.standard",
            vpc_id="vpc-miltj87lh2ww5smt1bxxxxx",
            message_retention=1,
            endpoints={
                "public": {
                    "eip_id": "eip-3nriu2y2ufwu8931exxxxx",
                },
                "overlay": {
                    "vpc_ids": ["vpc-miltj87lh2ww5smt1bxxxxx"],
                },
            },
            security_group_id_lists=["sg-3nqnz9en1ucxs931eaxxxxx"],
            subnet_id_lists=["subnet-w02wsq25fitc865ykaxxxxx"],
            zone_id_lists=["cn-beijing-a"],
            tags=[{
                "key": "env",
                "type": "CUSTOM",
                "value": "test",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:bmq/instance:Instance example "instance_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] auto_renew: 是否开启自动续费，取值如下：true：开启自动续费。false：关闭自动续费。
        :param pulumi.Input[builtins.str] billing_period: 购买时长的单位，取值如下：MONTHLY：按月购买。YEARLY：按年购买。
        :param pulumi.Input[builtins.str] billing_type: 实例的计费方式，取值如下：POST：按量计费。MIX：包年包月。
        :param pulumi.Input[builtins.str] description: 实例的描述语句。
        :param pulumi.Input[builtins.str] eip_id: 实例是否开启公网访问。如果需要开启公网访问，请配置相同地域的公网 IP 的 ID。
        :param pulumi.Input[Union['InstanceEndpointsArgs', 'InstanceEndpointsArgsDict']] endpoints: 实例所有接入点响应数据。
        :param pulumi.Input[builtins.int] message_retention: 实例下所有 Topic 的消息保留时长，单位为小时。
        :param pulumi.Input[builtins.str] name: 自定设置 BMQ 实例的名称，约束限制如下：由小写字母、数字和中划线（-）组成。长度为 1~64 字符。
        :param pulumi.Input[builtins.str] project_name: 实例所属项目名称。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] security_group_id_lists: 实例使用安全组列表。
        :param pulumi.Input[builtins.str] specification: 实例规格。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] subnet_id_lists: 实例使用的子网列表。
        :param pulumi.Input[builtins.int] times: 包年包月类型实例的购买时长，单位为月。
        :param pulumi.Input[builtins.str] vpc_id: 实例所在VPC ID。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] zone_id_lists: 实例所在可用区列表。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: InstanceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        云原生消息引擎 100% 兼容 Apache Kafka 协议，基于云原生的全托管、高吞吐、低时延、高可用、高可扩展性、高稳定性的分布式消息引擎服务，支持灵活动态扩缩容和流批一体计算，提供企业级大数据量级的实时流数据处理能力，帮助您构建数据处理的“中枢神经系统”，广泛应用于日志收集、数据聚合、离线数据分析等业务场景。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        b_mq_instance_demo = bytepluscc.bmq.Instance("BMQInstanceDemo",
            name="BMQInstanceDemo",
            billing_type="POST",
            project_name="default",
            specification="bmq.standard",
            vpc_id="vpc-miltj87lh2ww5smt1bxxxxx",
            message_retention=1,
            endpoints={
                "public": {
                    "eip_id": "eip-3nriu2y2ufwu8931exxxxx",
                },
                "overlay": {
                    "vpc_ids": ["vpc-miltj87lh2ww5smt1bxxxxx"],
                },
            },
            security_group_id_lists=["sg-3nqnz9en1ucxs931eaxxxxx"],
            subnet_id_lists=["subnet-w02wsq25fitc865ykaxxxxx"],
            zone_id_lists=["cn-beijing-a"],
            tags=[{
                "key": "env",
                "type": "CUSTOM",
                "value": "test",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:bmq/instance:Instance example "instance_id"
        ```

        :param str resource_name: The name of the resource.
        :param InstanceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(InstanceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auto_renew: Optional[pulumi.Input[builtins.str]] = None,
                 billing_period: Optional[pulumi.Input[builtins.str]] = None,
                 billing_type: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 eip_id: Optional[pulumi.Input[builtins.str]] = None,
                 endpoints: Optional[pulumi.Input[Union['InstanceEndpointsArgs', 'InstanceEndpointsArgsDict']]] = None,
                 message_retention: Optional[pulumi.Input[builtins.int]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 security_group_id_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 specification: Optional[pulumi.Input[builtins.str]] = None,
                 subnet_id_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InstanceTagArgs', 'InstanceTagArgsDict']]]]] = None,
                 times: Optional[pulumi.Input[builtins.int]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 zone_id_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = InstanceArgs.__new__(InstanceArgs)

            __props__.__dict__["auto_renew"] = auto_renew
            __props__.__dict__["billing_period"] = billing_period
            if billing_type is None and not opts.urn:
                raise TypeError("Missing required property 'billing_type'")
            __props__.__dict__["billing_type"] = billing_type
            __props__.__dict__["description"] = description
            __props__.__dict__["eip_id"] = eip_id
            __props__.__dict__["endpoints"] = endpoints
            __props__.__dict__["message_retention"] = message_retention
            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__.__dict__["name"] = name
            if project_name is None and not opts.urn:
                raise TypeError("Missing required property 'project_name'")
            __props__.__dict__["project_name"] = project_name
            if security_group_id_lists is None and not opts.urn:
                raise TypeError("Missing required property 'security_group_id_lists'")
            __props__.__dict__["security_group_id_lists"] = security_group_id_lists
            if specification is None and not opts.urn:
                raise TypeError("Missing required property 'specification'")
            __props__.__dict__["specification"] = specification
            if subnet_id_lists is None and not opts.urn:
                raise TypeError("Missing required property 'subnet_id_lists'")
            __props__.__dict__["subnet_id_lists"] = subnet_id_lists
            __props__.__dict__["tags"] = tags
            __props__.__dict__["times"] = times
            if vpc_id is None and not opts.urn:
                raise TypeError("Missing required property 'vpc_id'")
            __props__.__dict__["vpc_id"] = vpc_id
            if zone_id_lists is None and not opts.urn:
                raise TypeError("Missing required property 'zone_id_lists'")
            __props__.__dict__["zone_id_lists"] = zone_id_lists
            __props__.__dict__["created_time"] = None
            __props__.__dict__["expiration_time"] = None
            __props__.__dict__["group_limit"] = None
            __props__.__dict__["instance_id"] = None
            __props__.__dict__["partition_limit"] = None
            __props__.__dict__["resource_tags"] = None
            __props__.__dict__["resources"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["topic_limit"] = None
        super(Instance, __self__).__init__(
            'bytepluscc:bmq/instance:Instance',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            auto_renew: Optional[pulumi.Input[builtins.str]] = None,
            billing_period: Optional[pulumi.Input[builtins.str]] = None,
            billing_type: Optional[pulumi.Input[builtins.str]] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            eip_id: Optional[pulumi.Input[builtins.str]] = None,
            endpoints: Optional[pulumi.Input[Union['InstanceEndpointsArgs', 'InstanceEndpointsArgsDict']]] = None,
            expiration_time: Optional[pulumi.Input[builtins.str]] = None,
            group_limit: Optional[pulumi.Input[builtins.int]] = None,
            instance_id: Optional[pulumi.Input[builtins.str]] = None,
            message_retention: Optional[pulumi.Input[builtins.int]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            partition_limit: Optional[pulumi.Input[builtins.int]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            resource_tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InstanceResourceTagArgs', 'InstanceResourceTagArgsDict']]]]] = None,
            resources: Optional[pulumi.Input[Union['InstanceResourcesArgs', 'InstanceResourcesArgsDict']]] = None,
            security_group_id_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            specification: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            subnet_id_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InstanceTagArgs', 'InstanceTagArgsDict']]]]] = None,
            times: Optional[pulumi.Input[builtins.int]] = None,
            topic_limit: Optional[pulumi.Input[builtins.int]] = None,
            vpc_id: Optional[pulumi.Input[builtins.str]] = None,
            zone_id_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None) -> 'Instance':
        """
        Get an existing Instance resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] auto_renew: 是否开启自动续费，取值如下：true：开启自动续费。false：关闭自动续费。
        :param pulumi.Input[builtins.str] billing_period: 购买时长的单位，取值如下：MONTHLY：按月购买。YEARLY：按年购买。
        :param pulumi.Input[builtins.str] billing_type: 实例的计费方式，取值如下：POST：按量计费。MIX：包年包月。
        :param pulumi.Input[builtins.str] created_time: 实例的创建时间。
        :param pulumi.Input[builtins.str] description: 实例的描述语句。
        :param pulumi.Input[builtins.str] eip_id: 实例是否开启公网访问。如果需要开启公网访问，请配置相同地域的公网 IP 的 ID。
        :param pulumi.Input[Union['InstanceEndpointsArgs', 'InstanceEndpointsArgsDict']] endpoints: 实例所有接入点响应数据。
        :param pulumi.Input[builtins.str] expiration_time: 实例过期时间。
        :param pulumi.Input[builtins.int] group_limit: 实例消费组数量上限。
        :param pulumi.Input[builtins.str] instance_id: 实例ID。
        :param pulumi.Input[builtins.int] message_retention: 实例下所有 Topic 的消息保留时长，单位为小时。
        :param pulumi.Input[builtins.str] name: 自定设置 BMQ 实例的名称，约束限制如下：由小写字母、数字和中划线（-）组成。长度为 1~64 字符。
        :param pulumi.Input[builtins.int] partition_limit: 实例分区数量上限。
        :param pulumi.Input[builtins.str] project_name: 实例所属项目名称。
        :param pulumi.Input[Union['InstanceResourcesArgs', 'InstanceResourcesArgsDict']] resources: 实例资源统计响应数据。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] security_group_id_lists: 实例使用安全组列表。
        :param pulumi.Input[builtins.str] specification: 实例规格。
        :param pulumi.Input[builtins.str] status: 实例的状态。取值如下：INITIALIZING：初始化中，INITIALIZATION*FAILED：初始化失败，RUNNING：运行中，MODIFYING：更新中，MODIFY*FAILED：更新失败，RELEASING：释放中，STOPPING：停止中，STOPPED：停止，RECOVERING：恢复中，EXCEPTION：异常，CAPACITY*EXPAXION*FAILED：扩容失败，EXPANDING*CAPACITY：扩容中，CANCEL*EXPANDING_CAPACITY：扩容取消中，RESTARTING：重启中，UNPAID：未支付
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] subnet_id_lists: 实例使用的子网列表。
        :param pulumi.Input[builtins.int] times: 包年包月类型实例的购买时长，单位为月。
        :param pulumi.Input[builtins.int] topic_limit: 实例Topic数量上限。
        :param pulumi.Input[builtins.str] vpc_id: 实例所在VPC ID。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] zone_id_lists: 实例所在可用区列表。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _InstanceState.__new__(_InstanceState)

        __props__.__dict__["auto_renew"] = auto_renew
        __props__.__dict__["billing_period"] = billing_period
        __props__.__dict__["billing_type"] = billing_type
        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["description"] = description
        __props__.__dict__["eip_id"] = eip_id
        __props__.__dict__["endpoints"] = endpoints
        __props__.__dict__["expiration_time"] = expiration_time
        __props__.__dict__["group_limit"] = group_limit
        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["message_retention"] = message_retention
        __props__.__dict__["name"] = name
        __props__.__dict__["partition_limit"] = partition_limit
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["resource_tags"] = resource_tags
        __props__.__dict__["resources"] = resources
        __props__.__dict__["security_group_id_lists"] = security_group_id_lists
        __props__.__dict__["specification"] = specification
        __props__.__dict__["status"] = status
        __props__.__dict__["subnet_id_lists"] = subnet_id_lists
        __props__.__dict__["tags"] = tags
        __props__.__dict__["times"] = times
        __props__.__dict__["topic_limit"] = topic_limit
        __props__.__dict__["vpc_id"] = vpc_id
        __props__.__dict__["zone_id_lists"] = zone_id_lists
        return Instance(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="autoRenew")
    def auto_renew(self) -> pulumi.Output[builtins.str]:
        """
        是否开启自动续费，取值如下：true：开启自动续费。false：关闭自动续费。
        """
        return pulumi.get(self, "auto_renew")

    @property
    @pulumi.getter(name="billingPeriod")
    def billing_period(self) -> pulumi.Output[builtins.str]:
        """
        购买时长的单位，取值如下：MONTHLY：按月购买。YEARLY：按年购买。
        """
        return pulumi.get(self, "billing_period")

    @property
    @pulumi.getter(name="billingType")
    def billing_type(self) -> pulumi.Output[builtins.str]:
        """
        实例的计费方式，取值如下：POST：按量计费。MIX：包年包月。
        """
        return pulumi.get(self, "billing_type")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        实例的创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        实例的描述语句。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="eipId")
    def eip_id(self) -> pulumi.Output[builtins.str]:
        """
        实例是否开启公网访问。如果需要开启公网访问，请配置相同地域的公网 IP 的 ID。
        """
        return pulumi.get(self, "eip_id")

    @property
    @pulumi.getter
    def endpoints(self) -> pulumi.Output['outputs.InstanceEndpoints']:
        """
        实例所有接入点响应数据。
        """
        return pulumi.get(self, "endpoints")

    @property
    @pulumi.getter(name="expirationTime")
    def expiration_time(self) -> pulumi.Output[builtins.str]:
        """
        实例过期时间。
        """
        return pulumi.get(self, "expiration_time")

    @property
    @pulumi.getter(name="groupLimit")
    def group_limit(self) -> pulumi.Output[builtins.int]:
        """
        实例消费组数量上限。
        """
        return pulumi.get(self, "group_limit")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[builtins.str]:
        """
        实例ID。
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="messageRetention")
    def message_retention(self) -> pulumi.Output[builtins.int]:
        """
        实例下所有 Topic 的消息保留时长，单位为小时。
        """
        return pulumi.get(self, "message_retention")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        自定设置 BMQ 实例的名称，约束限制如下：由小写字母、数字和中划线（-）组成。长度为 1~64 字符。
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="partitionLimit")
    def partition_limit(self) -> pulumi.Output[builtins.int]:
        """
        实例分区数量上限。
        """
        return pulumi.get(self, "partition_limit")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        实例所属项目名称。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="resourceTags")
    def resource_tags(self) -> pulumi.Output[Sequence['outputs.InstanceResourceTag']]:
        return pulumi.get(self, "resource_tags")

    @property
    @pulumi.getter
    def resources(self) -> pulumi.Output['outputs.InstanceResources']:
        """
        实例资源统计响应数据。
        """
        return pulumi.get(self, "resources")

    @property
    @pulumi.getter(name="securityGroupIdLists")
    def security_group_id_lists(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        实例使用安全组列表。
        """
        return pulumi.get(self, "security_group_id_lists")

    @property
    @pulumi.getter
    def specification(self) -> pulumi.Output[builtins.str]:
        """
        实例规格。
        """
        return pulumi.get(self, "specification")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        实例的状态。取值如下：INITIALIZING：初始化中，INITIALIZATION*FAILED：初始化失败，RUNNING：运行中，MODIFYING：更新中，MODIFY*FAILED：更新失败，RELEASING：释放中，STOPPING：停止中，STOPPED：停止，RECOVERING：恢复中，EXCEPTION：异常，CAPACITY*EXPAXION*FAILED：扩容失败，EXPANDING*CAPACITY：扩容中，CANCEL*EXPANDING_CAPACITY：扩容取消中，RESTARTING：重启中，UNPAID：未支付
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="subnetIdLists")
    def subnet_id_lists(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        实例使用的子网列表。
        """
        return pulumi.get(self, "subnet_id_lists")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.InstanceTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def times(self) -> pulumi.Output[builtins.int]:
        """
        包年包月类型实例的购买时长，单位为月。
        """
        return pulumi.get(self, "times")

    @property
    @pulumi.getter(name="topicLimit")
    def topic_limit(self) -> pulumi.Output[builtins.int]:
        """
        实例Topic数量上限。
        """
        return pulumi.get(self, "topic_limit")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Output[builtins.str]:
        """
        实例所在VPC ID。
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="zoneIdLists")
    def zone_id_lists(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        实例所在可用区列表。
        """
        return pulumi.get(self, "zone_id_lists")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'KeyMultiRegionConfiguration',
    'KeyMultiRegionConfigurationPrimaryKey',
    'KeyMultiRegionConfigurationReplicaKey',
    'KeyTag',
    'GetKeyMultiRegionConfigurationResult',
    'GetKeyMultiRegionConfigurationPrimaryKeyResult',
    'GetKeyMultiRegionConfigurationReplicaKeyResult',
    'GetKeyTagResult',
]

@pulumi.output_type
class KeyMultiRegionConfiguration(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "multiRegionKeyType":
            suggest = "multi_region_key_type"
        elif key == "primaryKey":
            suggest = "primary_key"
        elif key == "replicaKeys":
            suggest = "replica_keys"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in KeyMultiRegionConfiguration. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        KeyMultiRegionConfiguration.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        KeyMultiRegionConfiguration.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 multi_region_key_type: Optional[builtins.str] = None,
                 primary_key: Optional['outputs.KeyMultiRegionConfigurationPrimaryKey'] = None,
                 replica_keys: Optional[Sequence['outputs.KeyMultiRegionConfigurationReplicaKey']] = None):
        """
        :param builtins.str multi_region_key_type: 多区域密钥的类型。
        :param 'KeyMultiRegionConfigurationPrimaryKeyArgs' primary_key: 主多区域键的事务识别号和区域 ID。
        """
        if multi_region_key_type is not None:
            pulumi.set(__self__, "multi_region_key_type", multi_region_key_type)
        if primary_key is not None:
            pulumi.set(__self__, "primary_key", primary_key)
        if replica_keys is not None:
            pulumi.set(__self__, "replica_keys", replica_keys)

    @property
    @pulumi.getter(name="multiRegionKeyType")
    def multi_region_key_type(self) -> Optional[builtins.str]:
        """
        多区域密钥的类型。
        """
        return pulumi.get(self, "multi_region_key_type")

    @property
    @pulumi.getter(name="primaryKey")
    def primary_key(self) -> Optional['outputs.KeyMultiRegionConfigurationPrimaryKey']:
        """
        主多区域键的事务识别号和区域 ID。
        """
        return pulumi.get(self, "primary_key")

    @property
    @pulumi.getter(name="replicaKeys")
    def replica_keys(self) -> Optional[Sequence['outputs.KeyMultiRegionConfigurationReplicaKey']]:
        return pulumi.get(self, "replica_keys")


@pulumi.output_type
class KeyMultiRegionConfigurationPrimaryKey(dict):
    def __init__(__self__, *,
                 region: Optional[builtins.str] = None,
                 trn: Optional[builtins.str] = None):
        """
        :param builtins.str region: 多区域密钥的区域 ID。
        :param builtins.str trn: 多区域密钥的 TRN。
        """
        if region is not None:
            pulumi.set(__self__, "region", region)
        if trn is not None:
            pulumi.set(__self__, "trn", trn)

    @property
    @pulumi.getter
    def region(self) -> Optional[builtins.str]:
        """
        多区域密钥的区域 ID。
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter
    def trn(self) -> Optional[builtins.str]:
        """
        多区域密钥的 TRN。
        """
        return pulumi.get(self, "trn")


@pulumi.output_type
class KeyMultiRegionConfigurationReplicaKey(dict):
    def __init__(__self__, *,
                 region: Optional[builtins.str] = None,
                 trn: Optional[builtins.str] = None):
        """
        :param builtins.str region: 多区域密钥的区域 ID。
        :param builtins.str trn: 多区域密钥的转换。
        """
        if region is not None:
            pulumi.set(__self__, "region", region)
        if trn is not None:
            pulumi.set(__self__, "trn", trn)

    @property
    @pulumi.getter
    def region(self) -> Optional[builtins.str]:
        """
        多区域密钥的区域 ID。
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter
    def trn(self) -> Optional[builtins.str]:
        """
        多区域密钥的转换。
        """
        return pulumi.get(self, "trn")


@pulumi.output_type
class KeyTag(dict):
    def __init__(__self__, *,
                 key: Optional[builtins.str] = None,
                 value: Optional[builtins.str] = None):
        """
        :param builtins.str key: KMS密钥的标签键
        :param builtins.str value: KMS密钥的标签值
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[builtins.str]:
        """
        KMS密钥的标签键
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> Optional[builtins.str]:
        """
        KMS密钥的标签值
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetKeyMultiRegionConfigurationResult(dict):
    def __init__(__self__, *,
                 multi_region_key_type: builtins.str,
                 primary_key: 'outputs.GetKeyMultiRegionConfigurationPrimaryKeyResult',
                 replica_keys: Sequence['outputs.GetKeyMultiRegionConfigurationReplicaKeyResult']):
        """
        :param builtins.str multi_region_key_type: 多区域密钥的类型。
        :param 'GetKeyMultiRegionConfigurationPrimaryKeyArgs' primary_key: 主多区域键的事务识别号和区域 ID。
        :param Sequence['GetKeyMultiRegionConfigurationReplicaKeyArgs'] replica_keys: 副本多区域密钥的事务记录编号和区域 ID。
        """
        pulumi.set(__self__, "multi_region_key_type", multi_region_key_type)
        pulumi.set(__self__, "primary_key", primary_key)
        pulumi.set(__self__, "replica_keys", replica_keys)

    @property
    @pulumi.getter(name="multiRegionKeyType")
    def multi_region_key_type(self) -> builtins.str:
        """
        多区域密钥的类型。
        """
        return pulumi.get(self, "multi_region_key_type")

    @property
    @pulumi.getter(name="primaryKey")
    def primary_key(self) -> 'outputs.GetKeyMultiRegionConfigurationPrimaryKeyResult':
        """
        主多区域键的事务识别号和区域 ID。
        """
        return pulumi.get(self, "primary_key")

    @property
    @pulumi.getter(name="replicaKeys")
    def replica_keys(self) -> Sequence['outputs.GetKeyMultiRegionConfigurationReplicaKeyResult']:
        """
        副本多区域密钥的事务记录编号和区域 ID。
        """
        return pulumi.get(self, "replica_keys")


@pulumi.output_type
class GetKeyMultiRegionConfigurationPrimaryKeyResult(dict):
    def __init__(__self__, *,
                 region: builtins.str,
                 trn: builtins.str):
        """
        :param builtins.str region: 多区域密钥的区域 ID。
        :param builtins.str trn: 多区域密钥的 TRN。
        """
        pulumi.set(__self__, "region", region)
        pulumi.set(__self__, "trn", trn)

    @property
    @pulumi.getter
    def region(self) -> builtins.str:
        """
        多区域密钥的区域 ID。
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter
    def trn(self) -> builtins.str:
        """
        多区域密钥的 TRN。
        """
        return pulumi.get(self, "trn")


@pulumi.output_type
class GetKeyMultiRegionConfigurationReplicaKeyResult(dict):
    def __init__(__self__, *,
                 region: builtins.str,
                 trn: builtins.str):
        """
        :param builtins.str region: 多区域密钥的区域 ID。
        :param builtins.str trn: 多区域密钥的转换。
        """
        pulumi.set(__self__, "region", region)
        pulumi.set(__self__, "trn", trn)

    @property
    @pulumi.getter
    def region(self) -> builtins.str:
        """
        多区域密钥的区域 ID。
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter
    def trn(self) -> builtins.str:
        """
        多区域密钥的转换。
        """
        return pulumi.get(self, "trn")


@pulumi.output_type
class GetKeyTagResult(dict):
    def __init__(__self__, *,
                 key: builtins.str,
                 value: builtins.str):
        """
        :param builtins.str key: KMS密钥的标签键
        :param builtins.str value: KMS密钥的标签值
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> builtins.str:
        """
        KMS密钥的标签键
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> builtins.str:
        """
        KMS密钥的标签值
        """
        return pulumi.get(self, "value")


